@@ -97,7 +97,7 @@ class ActivityMonitorQuery(StaticQuery):
             return name
 
         table = Table(title="Activity monitor", show_lines=True)
-        console = Console()
+        console = Console(force_jupyter=False)
 
         table.add_column("Action name\n(Type)", overflow="fold")
         table.add_column("ID", overflow="fold")
