@@ -16,6 +16,7 @@
 For example:
     $ qctrl auth
 """
+import json
 import logging
 import os
 from pathlib import Path
@@ -43,6 +44,7 @@ from qctrl.queries import (
     GetWorkerInfoQuery,
 )
 from qctrl.queries.action_export import ActionExportQuery
+from qctrl.queries.action_input_export import ActionInputExportQuery
 from qctrl.scripts_utils import (
     TokenType,
     _process_output,
@@ -346,3 +348,40 @@ def action_export(
             _write_action_result_to_csv(saved_path, result)
 
             click.echo(f"The result has been saved to {saved_path}")
+
+
+@main.command(help="Export an action's input data into a json file.")
+@click.option(
+    "--api-root",
+    help="Custom Q-CTRL API base URL.",
+    default=DEFAULT_API_ROOT,
+    show_default=f"{DEFAULT_API_ROOT}",
+)
+@click.option(
+    "--oidc-url",
+    default=DEFAULT_OIDC_URL,
+    help="Custom Q-CTRL OIDC base URL.",
+    show_default=f"{DEFAULT_OIDC_URL}",
+)
+@click.option(
+    "--action-id", help="The ID of the Action input to export.", required=True
+)
+@click.option(
+    "--pathfile",
+    help="The path and filename to store the file at e.g ~/temp/action.json",
+    type=click.Path(file_okay=True, dir_okay=False),
+)
+def action_input_export(api_root, oidc_url, action_id, pathfile):
+    """
+    Exports action input data to a json file.
+    """
+    gql_api = create_gql_client(api_root, create_client_auth(oidc_url))
+    action_input_export_query = ActionInputExportQuery(gql_api)
+    result = action_input_export_query(action_id)
+
+    if not result:
+        click.echo("Unable to retrieve action input")
+    else:
+        # format and save the action input to file
+        json_result = json.loads(result)
+        _process_output(json_result, pathfile)
