@@ -274,7 +274,7 @@ def _get_latest_version(url) -> str:
     str
         The latest version.
     """
-    contents = requests.get(url).json()
+    contents = requests.get(url).json()  # pylint: disable=missing-timeout
     latest_version = contents["info"]["version"]
     return latest_version
 
